@@ -10,7 +10,7 @@
 #
 #find the best fitting phase  (in hours)
 "cosinor" <- 
-function(angle,x=NULL,code=NULL,period=24,opti=FALSE) {
+function(angle,x=NULL,code=NULL,period=24,plot=FALSE,opti=FALSE) {
 if (is.null(x)) {x <- angle[2:ncol(angle)]
                  angle<- angle[1]}   #this allows for easier input if the time is the first variable
 nvar <- dim(x)
@@ -18,7 +18,7 @@ if(is.null(code)) { fit <- cosinor1(angle,x,period=period,opti=opti)  #if there
 m.resp <- mean(x[1])
 s.resp <- sd(x[1])
  x <- NA   #just to avoid being told that x is a global
-curve(cos((x-fit[1,1])*pi/12)*s.resp+m.resp,add=TRUE)  #this draws the first fitted variable
+if(plot) {curve(cos((x-fit[1,1])*pi/12)*s.resp+m.resp,add=TRUE) } #this draws the first fitted variable
   }  else  { fit.list <- by(x,code,cosinor1,period=period,opti=opti)  #this is the case if code is specified
    ncases <- length(fit.list)
    fit<- matrix(unlist(fit.list),nrow=ncases,byrow=TRUE)
