@@ -1,6 +1,7 @@
 #modified Dec 10, 2008 to return 1 on diagonal if non-invertible
 #modifed March 20, 2009 to return smcs * variance if covariance matrix is desired
 #modified April 8, 2009 to remove bug introduced March 10 when using covar from data
+#modified Jan 14, 2010 to test if matrix before cov2cor call.
 "smc" <-
 function(R,covar =FALSE) {
 failed=FALSE
@@ -9,8 +10,9 @@ failed=FALSE
                                  vari <- diag(C)
                                  R <- cov2cor(C)
                                  } else {R <- cor(R,use="pairwise")}}  else {vari <- diag(R)
+                                 if (!is.matrix(R)) R <- as.matrix(R)
                                  R <- cov2cor(R)
-      if (!is.matrix(R)) R <- as.matrix(R)}
+                                 }
  R.inv <- try(solve(R),TRUE)
  if(class(R.inv)== as.character("try-error")) {smc <- rep(1,p)
  message("In smc, the correlation matrix was not invertible, smc's returned as 1s")} else  {smc <- 1 -1/diag(R.inv)
